==> kadu_0.5.0.orig.tar.gz: kadu/modules/account_management/translations/account_management_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AccountManagement</name>
    <message>
        <source>Unregister user</source>
        <translation>Sconnetti utente</translation>
    </message>
    <message>
        <source>Register &amp;new user</source>
        <translation>&amp;Registra nuovo utente</translation>
    </message>
    <message>
        <source>Remind &amp;password</source>
        <translation>Ricorda la &amp;password</translation>
    </message>
    <message>
        <source>&amp;Change password / email</source>
        <translation>&amp;Cambia la password / email</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>This dialog box allows you to change your current password or e-mail.</source>
        <translation>Questa finestr di dialogo permette di cambiare la password attuale e e-mail.</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>New email:</source>
        <translation>Nuovo e-mail:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Nuova password:</translation>
    </message>
    <message>
        <source>Retype new password:</source>
        <translation>Ripetu nuova password:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation>Cambia password</translation>
    </message>
    <message>
        <source>Error data typed in required fields.

Passwords typed in both fields (&quot;New password&quot; and &quot;Retype new password&quot;) should be the same!</source>
        <translation>Errore dati bnei campi richiesti.
Campi password devono contenere la stessa frase !</translation>
    </message>
    <message>
        <source>Change password / email</source>
        <translation>Cambia la password / email</translation>
    </message>
</context>
<context>
    <name>Register</name>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registra</translation>
    </message>
    <message>
        <source>Create config file</source>
        <translation>Crea file di configurazione</translation>
    </message>
    <message>
        <source>Write the newly obtained UIN and password into a clean configuration file
This will erase your current config file contents if you have one</source>
        <translation>Nuovo numero GG e password saranno salvati nell file di configurazione
Il vecchio file, se esiste, sarà sovrascritto</translation>
    </message>
    <message>
        <source>Register user</source>
        <translation>Registra nuovo utente</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Please fill out all fields</source>
        <translation>Compilare tutti i campi</translation>
    </message>
    <message>
        <source>Registration was successful. Your new number is %1.
Store it in a safe place along with the password.
Now add your friends to the userlist.</source>
        <translation>La registrazione riuscita. Il vostro nuovo numero è %1.
Conservilo insieme con la password in un luogo sicuro
Ora è possibile aggiungere i vostri amici alla lista dei contatti.</translation>
    </message>
    <message>
        <source>This dialog box allows you to register a new account.</source>
        <translation>Questa finestra di dialogo permette la registrazione nuovo acconto.</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>New email:</source>
        <translation>Nuovo e-mail:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Nuova password:</translation>
    </message>
    <message>
        <source>Retype new password:</source>
        <translation>Ripeti passwoed:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>Error data typed in required fields.

Passwords typed in both fields (&quot;New password&quot; and &quot;Retype new password&quot;) should be the same!</source>
        <translation>Dati errati nei campi.
Le password devo esser identiche !</translation>
    </message>
    <message>
        <source>An error has occured while registration. Please try again later.</source>
        <translation>Errore durante la registrazione. Devi riprovare più tardi.</translation>
    </message>
</context>
<context>
    <name>RemindPassword</name>
    <message>
        <source>Error during remind password</source>
        <translation>L&apos;errore durante ricorda  password</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>This dialog box allows you to ask server to remind your current password.</source>
        <translation>Questa finestra di dialogo permette di interrograe server per ricordare password d&apos;accesso.</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Email (as during registration):</source>
        <translation>E-mail (messo durante la registrazione):</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>Your password has been send on your email</source>
        <translation>La tua password sarà spedita via E-mail</translation>
    </message>
    <message>
        <source>Remind password</source>
        <translation>Ricorda la password</translation>
    </message>
</context>
<context>
    <name>Unregister</name>
    <message>
        <source>Unregister</source>
        <translation>Sconnetti utente</translation>
    </message>
    <message>
        <source>Unregister user</source>
        <translation>Sconnetti utente</translation>
    </message>
    <message>
        <source>Please fill out all fields</source>
        <translation>Compilare tutti i campi</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>No user</source>
        <translation>Nessun utente</translation>
    </message>
    <message>
        <source>Unregistation was successful. Now you don&apos;t have any GG number :(</source>
        <translation>Cancellazione account terminata con successo. Adesso no hai più numero GG:(</translation>
    </message>
    <message>
        <source>UIN and password</source>
        <translation>Numero GG e password</translation>
    </message>
    <message>
        <source>UIN:</source>
        <translation>Numero GG:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>An error has occured while unregistration. Please try again later.</source>
        <translation>Errore durante cancellazione account. Devi riprovare più tardi.</translation>
    </message>
    <message>
        <source>This dialog box allows you to unregister your account. Be aware of using this option. &lt;font color=&quot;red&quot;&gt;&lt;b&gt;It will permanently delete your UIN and you will not be able to use it later!&lt;/b&gt;&lt;/font&gt;</source>
        <translation>Questa finestra di dialogo permette la cancellazione permamente dell&apos;utente dal server GG.&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Devi renderti conto che questa operazione è irreversibile, non potrai mai più usare questo account in futuro !&lt;/b&gt;&lt;/font&gt;</translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.1.orig.tar.gz: kadu/modules/account_management/translations/account_management_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AccountManagement</name>
    <message>
        <source>Unregister user</source>
        <translation>Sconnetti utente</translation>
    </message>
    <message>
        <source>Register &amp;new user</source>
        <translation>&amp;Registra nuovo utente</translation>
    </message>
    <message>
        <source>Remind &amp;password</source>
        <translation>Ricorda la &amp;password</translation>
    </message>
    <message>
        <source>&amp;Change password / email</source>
        <translation>&amp;Cambia la password / email</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>This dialog box allows you to change your current password or e-mail.</source>
        <translation>Questa finestr di dialogo permette di cambiare la password attuale e e-mail.</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>New email:</source>
        <translation>Nuovo e-mail:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Nuova password:</translation>
    </message>
    <message>
        <source>Retype new password:</source>
        <translation>Ripetu nuova password:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>Error data typed in required fields.

Passwords typed in both fields (&quot;New password&quot; and &quot;Retype new password&quot;) should be the same!</source>
        <translation>Errore dati bnei campi richiesti.
Campi password devono contenere la stessa frase !</translation>
    </message>
    <message>
        <source>Change password / email</source>
        <translation>Cambia la password / email</translation>
    </message>
</context>
<context>
    <name>Register</name>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registra</translation>
    </message>
    <message>
        <source>Create config file</source>
        <translation>Crea file di configurazione</translation>
    </message>
    <message>
        <source>Write the newly obtained UIN and password into a clean configuration file
This will erase your current config file contents if you have one</source>
        <translation>Nuovo numero GG e password saranno salvati nell file di configurazione
Il vecchio file, se esiste, sarà sovrascritto</translation>
    </message>
    <message>
        <source>Register user</source>
        <translation>Registra nuovo utente</translation>
    </message>
    <message>
        <source>Please fill out all fields</source>
        <translation>Compilare tutti i campi</translation>
    </message>
    <message>
        <source>Registration was successful. Your new number is %1.
Store it in a safe place along with the password.
Now add your friends to the userlist.</source>
        <translation>La registrazione riuscita. Il vostro nuovo numero è %1.
Conservilo insieme con la password in un luogo sicuro
Ora è possibile aggiungere i vostri amici alla lista dei contatti.</translation>
    </message>
    <message>
        <source>This dialog box allows you to register a new account.</source>
        <translation>Questa finestra di dialogo permette la registrazione nuovo acconto.</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>New email:</source>
        <translation>Nuovo e-mail:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Nuova password:</translation>
    </message>
    <message>
        <source>Retype new password:</source>
        <translation>Ripeti passwoed:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>Error data typed in required fields.

Passwords typed in both fields (&quot;New password&quot; and &quot;Retype new password&quot;) should be the same!</source>
        <translation>Dati errati nei campi.
Le password devo esser identiche !</translation>
    </message>
    <message>
        <source>An error has occured while registration. Please try again later.</source>
        <translation>Errore durante la registrazione. Devi riprovare più tardi.</translation>
    </message>
    <message>
        <source>Email address you have entered is not valid</source>
        <translation>Indirizzo email è sbagliato</translation>
    </message>
</context>
<context>
    <name>RemindPassword</name>
    <message>
        <source>Error during remind password</source>
        <translation>L&apos;errore durante ricorda  password</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>This dialog box allows you to ask server to remind your current password.</source>
        <translation>Questa finestra di dialogo permette di interrograe server per ricordare password d&apos;accesso.</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Email (as during registration):</source>
        <translation>E-mail (messo durante la registrazione):</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>Your password has been send on your email</source>
        <translation>La tua password sarà spedita via E-mail</translation>
    </message>
    <message>
        <source>Remind password</source>
        <translation>Ricorda la password</translation>
    </message>
</context>
<context>
    <name>Unregister</name>
    <message>
        <source>Unregister</source>
        <translation>Sconnetti utente</translation>
    </message>
    <message>
        <source>Unregister user</source>
        <translation>Sconnetti utente</translation>
    </message>
    <message>
        <source>Please fill out all fields</source>
        <translation>Compilare tutti i campi</translation>
    </message>
    <message>
        <source>No user</source>
        <translation>Nessun utente</translation>
    </message>
    <message>
        <source>Unregistation was successful. Now you don&apos;t have any GG number :(</source>
        <translation>Cancellazione account terminata con successo. Adesso no hai più numero GG:(</translation>
    </message>
    <message>
        <source>UIN and password</source>
        <translation>Numero GG e password</translation>
    </message>
    <message>
        <source>UIN:</source>
        <translation>Numero GG:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>An error has occured while unregistration. Please try again later.</source>
        <translation>Errore durante cancellazione account. Devi riprovare più tardi.</translation>
    </message>
    <message>
        <source>This dialog box allows you to unregister your account. Be aware of using this option. &lt;font color=&quot;red&quot;&gt;&lt;b&gt;It will permanently delete your UIN and you will not be able to use it later!&lt;/b&gt;&lt;/font&gt;</source>
        <translation>Questa finestra di dialogo permette la cancellazione permamente dell&apos;utente dal server GG.&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Devi renderti conto che questa operazione è irreversibile, non potrai mai più usare questo account in futuro !&lt;/b&gt;&lt;/font&gt;</translation>
    </message>
</context>
</TS>
